@@ -1,18 +1,20 @@
 class AggregateConnector:
-    def __init__(self, state, connectors):
+    def __init__(self, state: dict, connectors: dict):
         self._state = state
         self._connectors = connectors
 
-    def state(self):
+    @property
+    def state(self) -> dict:
         state = {}
         for connector_id, connector_obj in self._connectors.items():
-            state[connector_id] = connector_obj.state()
+            state[connector_id] = connector_obj.state
         return state
- 
-    def insert(self):
+
+    @property
+    def insert(self) -> dict:
         insert_dict = {}
         for connector in self._connectors.values():
-            connector_insert = connector.insert()
+            connector_insert = connector.insert
             for table, records in connector_insert.items():
                 if table in insert_dict:
                     insert_dict[table].extend(records)
@@ -21,10 +23,11 @@ class AggregateConnector:
                     insert_dict[table].extend(records)
         return insert_dict
 
-    def delete(self):
+    @property
+    def delete(self) -> dict:
         delete_dict = {}
         for connector in self._connectors.values():
-            connector_delete = connector.delete()
+            connector_delete = connector.delete
             for table, records in connector_delete.items():
                 if table in delete_dict:
                     delete_dict[table].extend(records)
@@ -33,25 +36,38 @@ class AggregateConnector:
                     delete_dict[table].extend(records)
         return delete_dict
 
-    def schema(self):
+    @property
+    def schema(self) -> dict:
         schema_dict = {}
         for connector in self._connectors.values():
-            connector_schema = connector.schema()
+            connector_schema = connector.schema
             for table, schema in connector_schema.items():
                 if table not in schema_dict:
                     schema_dict[table] = schema
         return schema_dict
 
-    def has_more(self):
+    @property
+    def has_more(self) -> bool:
         for connector in self._connectors.values():
-            if connector.has_more():
+            if connector.has_more:
                 return True
         return False
 
-    def get_records(self):
-        for connector in self._connectors.values():
-            connector.get_records()
+    @property
+    def response(self) -> dict:
+        return {
+            "state": self.state,
+            "insert": self.insert,
+            "delete": self.delete,
+            "schema": self.schema,
+            "hasMore": self.has_more,
+        }
 
-    def reset_state(self):
+    def get_records(self) -> None:
+        if self.has_more():
+            for connector in self._connectors.values():
+                connector.get_records()
+
+    def reset_state(self) -> None:
         for connector in self._connectors.values():
-            connector.reset_state()
\ No newline at end of file
+            connector.reset_state()
